@@ -52,7 +52,7 @@ it is provided here if you have precomputed the first two arguments or at least
 you can reduce the needed amount of computations in the 'getBFst''.
 -}
 getBFst''
-  :: Ord a => (# Int, (a, b) #) -- ^ The first unboxed tuple of the index and the element of the array.
+  :: (Ord a, Ix i) => (# Int, (a, b) #) -- ^ The first unboxed tuple of the index and the element of the array.
   -> (# Int, (a, b) #) -- ^ The second unboxed tuple of the index and the element of the array.
   -> Array i (a, b) -- ^ The array of the pairs of the compared value and the result that is used in case the last argument is equal to the compared value.
   -> b -- ^ The default value that is used if no first element in the array tuples equals to the compared value.
@@ -64,7 +64,7 @@ getBFst'' (# (I# i#), k #) (# (I# j#), m #) arr def x
 {-# INLINE getBFst'' #-}
 
 -- | The meaning of the arguments is the same as for 'getBFst'''. Is used internally in it. 
-gBF3 :: Ord a => (# Int#, (a, b) #) -> (# Int#, (a, b) #) -> Array i (a, b) -> b -> a -> b
+gBF3 :: (Ord a, Ix i) => (# Int#, (a, b) #) -> (# Int#, (a, b) #) -> Array i (a, b) -> b -> a -> b
 gBF3 (# !i#, k #) (# !j#, m #) arr def x
  | isTrue# ((j# -# i#) ># 1# ) = 
     case compare x (fst p) of
